[PATCH 5/6] binman: Rename TYPE_STAGE to TYPE_LEGACY_STAGE

Simon Glass sjg at chromium.org
Sat Oct 14 22:40:29 CEST 2023


In preparation for changing how stages are stored, rename the existing
stage tag.

Signed-off-by: Simon Glass <sjg at chromium.org>
---

 cmd/cbfs.c                     |  2 +-
 include/cbfs.h                 |  2 +-
 tools/binman/cbfs_util.py      | 12 ++++++------
 tools/binman/cbfs_util_test.py |  3 ++-
 4 files changed, 10 insertions(+), 9 deletions(-)

diff --git a/cmd/cbfs.c b/cmd/cbfs.c
index 8a61f2c26f9e..3cfc9eb27270 100644
--- a/cmd/cbfs.c
+++ b/cmd/cbfs.c
@@ -118,7 +118,7 @@ static int do_cbfs_ls(struct cmd_tbl *cmdtp, int flag, int argc,
 		case CBFS_TYPE_CBFSHEADER:
 			type_name = "cbfs header";
 			break;
-		case CBFS_TYPE_STAGE:
+		case CBFS_TYPE_LEGACY_STAGE:
 			type_name = "stage";
 			break;
 		case CBFS_TYPE_PAYLOAD:
diff --git a/include/cbfs.h b/include/cbfs.h
index 38efb1d2b02e..2bc5de2297e4 100644
--- a/include/cbfs.h
+++ b/include/cbfs.h
@@ -22,7 +22,7 @@ enum cbfs_result {
 enum cbfs_filetype {
 	CBFS_TYPE_BOOTBLOCK = 0x01,
 	CBFS_TYPE_CBFSHEADER = 0x02,
-	CBFS_TYPE_STAGE = 0x10,
+	CBFS_TYPE_LEGACY_STAGE = 0x10,
 	CBFS_TYPE_PAYLOAD = 0x20,
 	CBFS_TYPE_SELF = CBFS_TYPE_PAYLOAD,
 
diff --git a/tools/binman/cbfs_util_test.py b/tools/binman/cbfs_util_test.py
index 64592525ec7d..2775d05b8120 100755
--- a/tools/binman/cbfs_util_test.py
+++ b/tools/binman/cbfs_util_test.py
@@ -490,7 +490,8 @@ class TestCbfs(unittest.TestCase):
         load = 0xfef20000
         entry = load + 2
 
-        cfile = self._check_uboot(cbfs, cbfs_util.TYPE_STAGE, offset=0x20,
+        cfile = self._check_uboot(cbfs, cbfs_util.TYPE_LEGACY_STAGE,
+                                  offset=0x20,
                                   data=U_BOOT_DATA + U_BOOT_DTB_DATA)
 
         self.assertEqual(entry, cfile.entry)
diff --git a/tools/binman/cbfs_util.py b/tools/binman/cbfs_util.py
index 076768ae839b..9ca32f7309ff 100644
--- a/tools/binman/cbfs_util.py
+++ b/tools/binman/cbfs_util.py
@@ -96,7 +96,7 @@ ARCH_NAMES = {
 
 # File types. Only supported ones are included here
 TYPE_CBFSHEADER     = 0x02   # Master header, HEADER_FORMAT
-TYPE_STAGE          = 0x10   # Stage, holding an executable, see STAGE_FORMAT
+TYPE_LEGACY_STAGE   = 0x10   # Stage, holding an executable
 TYPE_RAW            = 0x50   # Raw file, possibly compressed
 TYPE_EMPTY          = 0xffffffff     # Empty data
 
@@ -265,7 +265,7 @@ class CbfsFile(object):
         Returns:
             CbfsFile object containing the file information
         """
-        cfile = CbfsFile(name, TYPE_STAGE, data, cbfs_offset)
+        cfile = CbfsFile(name, TYPE_LEGACY_STAGE, data, cbfs_offset)
         cfile.base_address = base_address
         return cfile
 
@@ -326,7 +326,7 @@ class CbfsFile(object):
         """
         name = _pack_string(self.name)
         hdr_len = len(name) + FILE_HEADER_LEN
-        if self.ftype == TYPE_STAGE:
+        if self.ftype == TYPE_LEGACY_STAGE:
             pass
         elif self.ftype == TYPE_RAW:
             if self.compress:
@@ -354,7 +354,7 @@ class CbfsFile(object):
         attr = b''
         pad = b''
         data = self.data
-        if self.ftype == TYPE_STAGE:
+        if self.ftype == TYPE_LEGACY_STAGE:
             elf_data = elf.DecodeElf(data, self.base_address)
             content = struct.pack(STAGE_FORMAT, self.compress,
                                   elf_data.entry, elf_data.load,
@@ -639,7 +639,7 @@ class CbfsReader(object):
         files: Ordered list of CbfsFile objects
         align: Alignment to use for files, typically ENTRT_ALIGN
         stage_base_address: Base address to use when mapping ELF files into the
             CBFS for TYPE_STAGE files. If this is larger than the code address
             of the ELF file, then data at the start of the ELF file will not
             appear in the CBFS. Currently there are no tests for behaviour as
             documentation is sparse
@@ -750,7 +750,7 @@ class CbfsReader(object):
         fd.seek(cbfs_offset, io.SEEK_SET)
         if ftype == TYPE_CBFSHEADER:
             self._read_header(fd)
-        elif ftype == TYPE_STAGE:
+        elif ftype == TYPE_LEGACY_STAGE:
             data = fd.read(STAGE_LEN)
             cfile = CbfsFile.stage(self.stage_base_address, name, b'',
                                    cbfs_offset)
@@ -639,7 +639,7 @@ class CbfsReader(object):
         align: Alignment to use for files, typically ENTRT_ALIGN
         stage_base_address: Base address to use when mapping ELF files into the
-            CBFS for TYPE_STAGE files. If this is larger than the code address
+            CBFS for TYPE_LEGACY_STAGE files. If this is larger than the code address
             of the ELF file, then data at the start of the ELF file will not
             appear in the CBFS. Currently there are no tests for behaviour as
-- 
2.42.0.655.g421f12c284-goog



More information about the U-Boot mailing list